==> nmrium-0.50.1.tgz: package/lib/component/panels/databasePanel/DatabaseTable.js <==
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import lodashGet from 'lodash/get';
import { useMemo, memo } from 'react';
import { ResponsiveChart } from 'react-d3-utils';
import { FaDownload, FaPlus } from 'react-icons/fa';
import { IdcodeSvgRenderer, SmilesSvgRenderer } from 'react-ocl/full';
import Button from '../../elements/Button';
import { ColumnWrapper } from '../../elements/ColumnWrapper';
import ReactTable from '../../elements/ReactTable/ReactTable';
import addCustomColumn from '../../elements/ReactTable/utility/addCustomColumn';
import { HighlightEventSource } from '../../highlight';
import { usePanelPreferences } from '../../hooks/usePanelPreferences';
import { formatNumber } from '../../utility/formatNumber';
const overFlowStyle = {
    overflow: 'hidden',
    whiteSpace: 'nowrap',
    textOverflow: 'ellipsis',
};
const databaseTableColumns = (databasePreferences) => [
    {
        showWhen: 'showNames',
        index: 1,
        Header: 'names',
        accessor: (row) => (row.names ? row.names.join(',') : ''),
        enableRowSpan: true,
        style: {
            width: '100px',
            minWidth: '100px',
            maxWidth: '100px',
            ...overFlowStyle,
        },
    },
    {
        showWhen: 'range.show',
        index: 2,
        Header: 'From - To',
        accessor: (row) => {
            const rangeFormat = databasePreferences.range.format;
            return row?.from && row?.to
                ? `${formatNumber(row.from, rangeFormat)} - ${formatNumber(row.to, rangeFormat)}`
                : '';
        },
        enableRowSpan: true,
    },
    {
        showWhen: 'delta.show',
        index: 3,
        Header: 'δ (ppm)',
        accessor: 'delta',
        Cell: ({ row }) => row.original.delta
            ? formatNumber(row.original.delta, databasePreferences.delta.format)
            : '',
    },
    {
        showWhen: 'showAssignment',
        index: 4,
        Header: 'Assignment',
        accessor: 'assignment',
    },
    {
        showWhen: 'showMultiplicity',
        index: 5,
        Header: 'Multi.',
        accessor: 'multiplicity',
    },
    {
        showWhen: 'coupling.show',
        index: 6,
        Header: 'J (Hz)',
        accessor: (row) => {
            if (!row?.coupling) {
                return '';
            }
            else {
                return row.coupling
                    .split(',')
                    .map((value) => formatNumber(value, databasePreferences.coupling.format))
                    .join(',');
            }
        },
        style: {
            width: '60px',
            minWidth: '60px',
            ...overFlowStyle,
        },
    },
    {
        showWhen: 'showSolvent',
        index: 7,
        Header: 'Solvent',
        accessor: 'solvent',
        style: {
            width: '80px',
            minWidth: '80px',
            ...overFlowStyle,
        },
    },
    {
        showWhen: 'showSmiles',
        index: 8,
        Header: 'structure',
        accessor: 'index',
        style: { height: 0 },
        enableRowSpan: true,
        Cell({ row }) {
            const { idCode, coordinates } = row.original?.ocl || {};
            const smiles = row.original?.smiles;
            return (_jsx(ResponsiveChart, { children: ({ width, height }) => {
                    if (idCode && coordinates) {
                        return (_jsx(IdcodeSvgRenderer, { height: height, width: width, idcode: idCode, coordinates: coordinates }));
                    }
                    else if (smiles) {
                        return (_jsx(SmilesSvgRenderer, { height: height, width: width, smiles: smiles }));
                    }
                    else {
                        return null;
                    }
                } }));
        },
    },
];
function DatabaseTable({ data, onAdd, onSave, totalCount, }) {
    const databasePreferences = usePanelPreferences('database');
    const initialColumns = useMemo(() => [
        {
            index: 10,
            id: 'add-button',
            Header: '',
            style: {
                width: '1%',
                maxWidth: '60px',
                minWidth: '60px',
                padding: 0,
            },
            accessor: 'index',
            enableRowSpan: true,
            Cell: ({ row }) => {
                const { jcampURL } = row.original;
                return (_jsxs(ColumnWrapper, { style: { display: 'flex', justifyContent: 'space-evenly' }, children: [_jsx(Button.Done, { style: { padding: '0.25rem', fontSize: '0.7rem' }, fill: "outline", onClick: () => onAdd(row.original), children: _jsx(FaPlus, {}) }), databasePreferences?.allowSaveAsNMRium && (_jsx(Button.Action, { style: { padding: '0.25rem', fontSize: '0.7rem' }, fill: "outline", onClick: () => onSave(row.original), disabled: !jcampURL, children: _jsx(FaDownload, {}) }))] }));
            },
        },
    ], [databasePreferences?.allowSaveAsNMRium, onAdd, onSave]);
    const tableColumns = useMemo(() => {
        const columns = [...initialColumns];
        for (const col of databaseTableColumns(databasePreferences)) {
            const { showWhen, ...colParams } = col;
            if (lodashGet(databasePreferences, showWhen, false)) {
                addCustomColumn(columns, colParams);
            }
        }
        return columns.sort((object1, object2) => object1.index - object2.index);
    }, [databasePreferences, initialColumns]);
    return (_jsx(ReactTable, { data: data, columns: tableColumns, highlightedSource: HighlightEventSource.DATABASE, groupKey: "index", approxItemHeight: 23.5, enableVirtualScroll: true, totalCount: totalCount, disableDefaultRowStyle: true }));
}
export default memo(DatabaseTable);

==> nmrium-0.56.0.tgz: package/lib/component/panels/databasePanel/DatabaseTable.js <==
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import lodashGet from 'lodash/get';
import { useMemo, memo } from 'react';
import { ResponsiveChart } from 'react-d3-utils';
import { FaDownload, FaPlus } from 'react-icons/fa';
import { IdcodeSvgRenderer, SmilesSvgRenderer } from 'react-ocl/full';
import Button from '../../elements/Button';
import { ColumnWrapper } from '../../elements/ColumnWrapper';
import ReactTable from '../../elements/ReactTable/ReactTable';
import addCustomColumn from '../../elements/ReactTable/utility/addCustomColumn';
import { HighlightEventSource } from '../../highlight';
import { usePanelPreferences } from '../../hooks/usePanelPreferences';
import { formatNumber } from '../../utility/formatNumber';
const overFlowStyle = {
    overflow: 'hidden',
    whiteSpace: 'nowrap',
    textOverflow: 'ellipsis',
};
const databaseTableColumns = (databasePreferences) => [
    {
        showWhen: 'showNames',
        index: 1,
        Header: 'names',
        accessor: (row) => (row.names ? row.names.join(',') : ''),
        enableRowSpan: true,
        style: {
            width: '100px',
            minWidth: '100px',
            maxWidth: '100px',
            ...overFlowStyle,
        },
    },
    {
        showWhen: 'range.show',
        index: 2,
        Header: 'From - To',
        accessor: (row) => {
            const rangeFormat = databasePreferences.range.format;
            return row?.from && row?.to
                ? `${formatNumber(row.from, rangeFormat)} - ${formatNumber(row.to, rangeFormat)}`
                : '';
        },
        enableRowSpan: true,
    },
    {
        showWhen: 'delta.show',
        index: 3,
        Header: 'δ (ppm)',
        accessor: 'delta',
        Cell: ({ row }) => row.original.delta
            ? formatNumber(row.original.delta, databasePreferences.delta.format)
            : '',
    },
    {
        showWhen: 'showAssignment',
        index: 4,
        Header: 'Assignment',
        accessor: 'assignment',
    },
    {
        showWhen: 'showMultiplicity',
        index: 5,
        Header: 'Multi.',
        accessor: 'multiplicity',
    },
    {
        showWhen: 'coupling.show',
        index: 6,
        Header: 'J (Hz)',
        accessor: (row) => {
            if (!row?.coupling) {
                return '';
            }
            else {
                return row.coupling
                    .split(',')
                    .map((value) => formatNumber(value, databasePreferences.coupling.format))
                    .join(',');
            }
        },
        style: {
            width: '60px',
            minWidth: '60px',
            ...overFlowStyle,
        },
    },
    {
        showWhen: 'showSolvent',
        index: 7,
        Header: 'Solvent',
        accessor: 'solvent',
        style: {
            width: '80px',
            minWidth: '80px',
            ...overFlowStyle,
        },
    },
    {
        showWhen: 'showSmiles',
        index: 8,
        Header: 'structure',
        accessor: 'index',
        style: { height: 0 },
        enableRowSpan: true,
        Cell({ row }) {
            const { idCode, coordinates } = row.original?.ocl || {};
            const smiles = row.original?.smiles;
            return (_jsx(ResponsiveChart, { minWidth: 50, minHeight: 23, children: ({ width, height }) => {
                    if (idCode && coordinates) {
                        return (_jsx(IdcodeSvgRenderer, { height: height, width: width, idcode: idCode, coordinates: coordinates }));
                    }
                    else if (smiles) {
                        return (_jsx(SmilesSvgRenderer, { height: height, width: width, smiles: smiles }));
                    }
                    else {
                        return null;
                    }
                } }));
        },
    },
];
function DatabaseTable({ data, onAdd, onSave, totalCount, }) {
    const databasePreferences = usePanelPreferences('database');
    const initialColumns = useMemo(() => [
        {
            index: 10,
            id: 'add-button',
            Header: '',
            style: {
                width: '1%',
                maxWidth: '60px',
                minWidth: '60px',
                padding: 0,
            },
            accessor: 'index',
            enableRowSpan: true,
            Cell: ({ row }) => {
                const { jcampURL } = row.original;
                return (_jsxs(ColumnWrapper, { style: { display: 'flex', justifyContent: 'space-evenly' }, children: [_jsx(Button.Done, { style: { padding: '0.25rem', fontSize: '0.7rem' }, fill: "outline", onClick: () => onAdd(row.original), children: _jsx(FaPlus, {}) }), databasePreferences?.allowSaveAsNMRium && (_jsx(Button.Action, { style: { padding: '0.25rem', fontSize: '0.7rem' }, fill: "outline", onClick: () => onSave(row.original), disabled: !jcampURL, children: _jsx(FaDownload, {}) }))] }));
            },
        },
    ], [databasePreferences?.allowSaveAsNMRium, onAdd, onSave]);
    const tableColumns = useMemo(() => {
        const columns = [...initialColumns];
        for (const col of databaseTableColumns(databasePreferences)) {
            const { showWhen, ...colParams } = col;
            if (lodashGet(databasePreferences, showWhen, false)) {
                addCustomColumn(columns, colParams);
            }
        }
        return columns.sort((object1, object2) => object1.index - object2.index);
    }, [databasePreferences, initialColumns]);
    return (_jsx(ReactTable, { data: data, columns: tableColumns, highlightedSource: HighlightEventSource.DATABASE, groupKey: "index", approxItemHeight: 23, enableVirtualScroll: true, totalCount: totalCount, disableDefaultRowStyle: true }));
}
export default memo(DatabaseTable);
